summaryrefslogtreecommitdiff
path: root/chromium/v8/src/codegen/arm/assembler-arm.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/v8/src/codegen/arm/assembler-arm.cc')
-rw-r--r--chromium/v8/src/codegen/arm/assembler-arm.cc13
1 files changed, 7 insertions, 6 deletions
diff --git a/chromium/v8/src/codegen/arm/assembler-arm.cc b/chromium/v8/src/codegen/arm/assembler-arm.cc
index c8ef586fc15..7ca49a3f9fc 100644
--- a/chromium/v8/src/codegen/arm/assembler-arm.cc
+++ b/chromium/v8/src/codegen/arm/assembler-arm.cc
@@ -2210,7 +2210,7 @@ void Assembler::stm(BlockAddrMode am, Register base, RegList src,
// Exception-generating instructions and debugging support.
// Stops with a non-negative code less than kNumOfWatchedStops support
// enabling/disabling and a counter feature. See simulator-arm.h .
-void Assembler::stop(const char* msg, Condition cond, int32_t code) {
+void Assembler::stop(Condition cond, int32_t code) {
#ifndef __arm__
DCHECK_GE(code, kDefaultStopCode);
{
@@ -4827,12 +4827,13 @@ void Assembler::RecordRelocInfo(RelocInfo::Mode rmode, intptr_t data) {
void Assembler::ConstantPoolAddEntry(int position, RelocInfo::Mode rmode,
intptr_t value) {
DCHECK(rmode != RelocInfo::CONST_POOL);
// We can share CODE_TARGETs because we don't patch the code objects anymore,
// and we make sure we emit only one reloc info for them (thus delta patching)
// will apply the delta only once. At the moment, we do not dedup code targets
// if they are wrapped in a heap object request (value == 0).
bool sharing_ok = RelocInfo::IsShareableRelocMode(rmode) ||
- (rmode == RelocInfo::CODE_TARGET && value != 0);
+ (rmode == RelocInfo::CODE_TARGET && value != 0) ||
+ (RelocInfo::IsEmbeddedObjectMode(rmode) && value != 0);
DCHECK_LT(pending_32_bit_constants_.size(), kMaxNumPending32Constants);
if (pending_32_bit_constants_.empty()) {
first_const_pool_32_use_ = position;
@@ -4827,12 +4827,13 @@ void Assembler::RecordRelocInfo(RelocInfo::Mode rmode, intptr_t data) {
intptr_t value) {
DCHECK(rmode != RelocInfo::CONST_POOL);
- // We can share CODE_TARGETs because we don't patch the code objects anymore,
- // and we make sure we emit only one reloc info for them (thus delta patching)
- // will apply the delta only once. At the moment, we do not dedup code targets
- // if they are wrapped in a heap object request (value == 0).
+ // We can share CODE_TARGETs and embedded objects, but we must make sure we
+ // only emit one reloc info for them (thus delta patching will apply the delta
+ // only once). At the moment, we do not deduplicate heap object request which
+ // are indicated by value == 0.
bool sharing_ok = RelocInfo::IsShareableRelocMode(rmode) ||